# LN-Studio

LN-Studio is a GUI Application to create, run and debug [LiveNodes graphs](https://livenodes.pages.csl.uni-bremen.de/livenodes/). 
It enables live sensor recording, processing and machine learning for interactive low-latency research applications.

```{eval-rst}
.. toctree::
    :caption: Start
    :maxdepth: 2

    readme.rst


.. toctree::
    :caption: Modules
    :maxdepth: 2

    modules/modules.rst


.. toctree::
    :caption: Repository
    :maxdepth: 2

    contributing.rst
    authors.rst
    changelog.rst


```


